import cleanDeep from 'clean-deep';
import { diff } from 'deep-object-diff';
import omitDeep from 'omit-deep-lodash';

var OMIT_PROPERTIES = ['__typename', 'id', 'updated_at', 'created_at'];
function cleanGqlInput(entity, omit) {
  if (omit === void 0) {
    omit = OMIT_PROPERTIES;
  }

  return sortObject( // cleanDeep( Removes empty objects, arrays, empty strings, NaN, null and undefined values from objects.
  omitDeep.apply(void 0, [// removes unwanted properties
  entity].concat(omit)));
}
function cleanDiff(originalObj, updatedObj) {
  return cleanDeep(diff(cleanGqlInput(originalObj), cleanGqlInput(updatedObj)), {
    emptyArrays: true,
    emptyObjects: true,
    emptyStrings: false
  });
} // from https://github.com/IndigoUnited/js-deep-sort-object/blob/master/index.js

function isPlainObject(obj) {
  return Object.prototype.toString.call(obj) === '[object Object]';
}

function defaultSortFn(a, b) {
  return a.localeCompare(b);
}

function sortObject(src, comparator) {
  if (Array.isArray(src)) {
    return src.map(function (item) {
      return sortObject(item, comparator);
    });
  }

  if (isPlainObject(src)) {
    var out = {};
    Object.keys(src).sort(comparator || defaultSortFn).forEach(function (key) {
      out[key] = sortObject(src[key], comparator);
    });
    return out;
  }

  return src;
}

export { OMIT_PROPERTIES, cleanDiff, cleanGqlInput, sortObject };
//# sourceMappingURL=graphql-clean-diff.esm.js.map
